// ============================================================================
// ==                                                                        ==
// == AMDiS - Adaptive multidimensional simulations                          ==
// ==                                                                        ==
// ============================================================================
// ==                                                                        ==
// ==  crystal growth group                                                  ==
// ==                                                                        ==
// ==  Stiftung caesar                                                       ==
// ==  Ludwig-Erhard-Allee 2                                                 ==
// ==  53175 Bonn                                                            ==
// ==  germany                                                               ==
// ==                                                                        ==
// ============================================================================
// ==                                                                        ==
// ==  http://www.caesar.de/cg/AMDiS                                         ==
// ==                                                                        ==
// ============================================================================

/** \file ElementMatrix.h */

#ifndef AMDIS_ELEMENTMATRIX_H
#define AMDIS_ELEMENTMATRIX_H

#include "MemoryManager.h"
#include "MatrixVector.h"

namespace AMDiS {

  // =============================================================================
  // ===== class ElementMatrix ===================================================
  // =============================================================================

  /** \ingroup Assembler
   *  
   * \brief
   * Stores a single element matrix and the corresponding row and column 
   * dof indices.
   */
  class ElementMatrix : public Matrix<double>
  {
  public:
    MEMORY_MANAGED(ElementMatrix);

    /** \brief
     * Constructor.
     */
    ElementMatrix(int numRows, int numCols) 
      : Matrix<double>(numRows, numCols),
	rowIndices(numRows),
	colIndices(numCols)
    {};

  public:
    /** \brief
     * row dof indices.
     */
    Vector<DegreeOfFreedom> rowIndices;

    /** \brief
     * column dof indices.
     */
    Vector<DegreeOfFreedom> colIndices;
  };

}

#endif // AMDIS_ELEMENTMATRIX_H
