// ============================================================================
// ==                                                                        ==
// == AMDiS - Adaptive multidimensional simulations                          ==
// ==                                                                        ==
// ============================================================================
// ==                                                                        ==
// ==  crystal growth group                                                  ==
// ==                                                                        ==
// ==  Stiftung caesar                                                       ==
// ==  Ludwig-Erhard-Allee 2                                                 ==
// ==  53175 Bonn                                                            ==
// ==  germany                                                               ==
// ==                                                                        ==
// ============================================================================
// ==                                                                        ==
// ==  http://www.caesar.de/cg/AMDiS                                         ==
// ==                                                                        ==
// ============================================================================

/** \file ElementVector.h */

#ifndef AMDIS_ELEMENTVECTOR_H
#define AMDIS_ELEMENTVECTOR_H

#include "MemoryManager.h"
#include "MatrixVector.h"

namespace AMDiS {

  // =============================================================================
  // ===== class ElementVector ===================================================
  // =============================================================================

  /** \ingroup Assembler
   *  
   * \brief
   * Stores a single element vector and the corresponding dof indices.
   */
  class ElementVector : public Vector<double>
  {
  public:
    MEMORY_MANAGED(ElementVector);

    /** \brief
     * Constructor.
     */
    ElementVector(int size) 
      : Vector<double>(size),
	dofIndices(size)
    {};

  public:
    /** \brief
     * dof indices.
     */
    Vector<DegreeOfFreedom> dofIndices;
  };

}

#endif // AMDIS_ELEMENTVECTOR_H
